intelmq.bots.collectors.blueliv package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.blueliv package

## Submodules

## intelmq.bots.collectors.blueliv.collector_crimeserver module

`intelmq.bots.collectors.blueliv.collector_crimeserver.` `BOT`

  alias of `intelmq.bots.collectors.blueliv.collector_crimeserver.BluelivCrimeserverCollectorBot`

class `intelmq.bots.collectors.blueliv.collector_crimeserver.` `BluelivCrimeserverCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `init`()
  `process`()

## Module contents